package com.community.huiju.controller;

import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.config.entity.UserElement;
import com.community.huiju.model.TaUser;
import com.community.huiju.model.TpTicket;
import com.community.huiju.model.TpTransaction;
import com.community.huiju.model.TpTicketRecordComment;
import com.community.huiju.service.ITicketService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.Example;
import io.swagger.annotations.ExampleProperty;
import lombok.val;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cloud.context.config.annotation.RefreshScope;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpSession;
import java.util.List;

@RestController
@RefreshScope
@RequestMapping("/")
@Api(value = "工单相关的API",description = "工单相关的API")
public class TicketController {

    @Autowired
    private ITicketService iTicketService;

    @RequestMapping(value = "/tickets/{communityId}",method = RequestMethod.GET)
    @ApiOperation(value = "获取 报修/投诉/联系单 各3条数据",notes = "根据 小区编号,第几页,一页多少行")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path",dataType = "String",name = "communityId",value = "小区编号"),
            @ApiImplicitParam(paramType = "query",dataType = "Integer",name = "pageNum",value = "第几页"),
            @ApiImplicitParam(paramType = "query",dataType = "Integer",name = "pageSize",value = "一页多少数据"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token"),
    })
    public ResponseBean getService(@PathVariable(value = "communityId") String communityId,
                                   @RequestParam(value = "pageNum",defaultValue = "1") Integer pageNum,
                                   @RequestParam(value = "pageSize",defaultValue = "3") Integer pageSize,
                                   HttpSession session) {
        ResponseBean response = new ResponseBean();

        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);

        TpTicket tpTicket = new TpTicket();
        tpTicket.setCommunityId(Integer.valueOf(communityId));
        tpTicket.setTaUserId(userElement.getId());

        response = iTicketService.getList(tpTicket,pageNum,pageSize);
        return response;
    }
    
    @ApiOperation(value = "获取报修/投诉/联系单进度详情数据",notes = "获取报修/投诉/联系单进度详情数据")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path",dataType = "String",name = "communityId",value = "小区编号"),
            @ApiImplicitParam(paramType = "query",dataType = "Integer",name = "ticketId",value = "报修id")
    })
    @RequestMapping(value = "/ticket/schedule/{communityId}", method = RequestMethod.GET)
    public ResponseBean getTicketSchedule(@PathVariable(value = "communityId") String communityId,@RequestParam Integer ticketId){
        ResponseBean responseBean = new ResponseBean();
        TpTicket ticket = iTicketService.getTicketSchedule(communityId,ticketId);
        responseBean.addSuccess(ticket);
        return responseBean;
    }
    
    @RequestMapping(value = "/tickets/list/{communityId}", method = RequestMethod.GET)
    @ApiOperation(value = "获取 报修/投诉/联系单 数据列表", notes = "根据 小区编号,工单类型,第几页,一页多少行")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "path",dataType = "String",name = "communityId", value = "小区编号"),
            @ApiImplicitParam(paramType = "query",dataType = "Integer",name = "pageNum", value = "第几页"),
            @ApiImplicitParam(paramType = "query",dataType = "Integer",name = "pageSize", value = "一页多少数据"),
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "type", value = "工单类型 (0报修/1投诉/2联系单)"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token"),
    })
    public ResponseBean getServiceList(@PathVariable(value = "communityId") String communityId,
                                       @RequestParam(value = "pageNum",defaultValue = "1") Integer pageNum,
                                       @RequestParam(value = "pageSize",defaultValue = "10") Integer pageSize,
                                       @RequestParam(value = "type") String type,
                                       HttpSession session) {
        ResponseBean responseBean = new ResponseBean();

        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);

        TpTicket tpTicket = new TpTicket();
        tpTicket.setCommunityId(Integer.valueOf(communityId));
        tpTicket.setTaUserId(userElement.getId());
        tpTicket.setType(type);

        responseBean = iTicketService.getByTypeList(tpTicket,pageNum,pageSize);

        return responseBean;

    }
    @ApiOperation(value = "回复 报修/投诉/联系单 追问接口", notes = "回复 报修/投诉/联系单 追问接口")
    @ApiImplicitParams({ @ApiImplicitParam(paramType = "path", dataType = "integer", name = "communityId", value = "小区Id"),
            @ApiImplicitParam(name = "tpTicketRecordComment", value = "回复记录参数", paramType ="body")})
    @RequestMapping(value = "/ticket/reply/{communityId}", method = RequestMethod.POST)
    public ResponseBean updateTicketsReply(@PathVariable(value = "communityId") Integer communityId, @RequestBody TpTicketRecordComment tpTicketRecordComment){
        ResponseBean responseBean = new ResponseBean();
        tpTicketRecordComment.setCommunityId(communityId);
        Integer size = iTicketService.updateTicketsReply(tpTicketRecordComment);
        if (size > 0){
            responseBean.addSuccess(size);
        }else{
            responseBean.addError("更新失败");
        }
        return responseBean;
    }

    @ApiOperation(value = "添加报修", notes = "添加报修")
    @ApiImplicitParams({
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "ticketContent",value = "工单内容"),
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "ticketTitle",value = "工单标题"),
            @ApiImplicitParam(paramType = "query",dataType = "String",name = "repairType",value = "报修房屋类型"),
            @ApiImplicitParam(paramType = "header",dataType = "String",name = "X-Auth-Token",value = "Token"),
    })
    @RequestMapping(value = "/addAlltpTicket",method = RequestMethod.POST)
    @ResponseBody
    public ResponseBean addTransaction(TpTicket tpTicket, HttpSession session){
        ResponseBean responseBean = new ResponseBean();
        UserElement userElement = (UserElement) session.getAttribute(Constant.APP_USER_SESSION);
        Integer userId=userElement.getId();
        ResponseBean response=iTicketService.addAiTicketService(userId,tpTicket);
        return response;
    }


}
