package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.constant.Constant;
import com.community.commom.mode.ResponseBean;
import com.community.huiju.dao.*;
import com.community.huiju.model.*;
import com.community.huiju.service.SocialServiceI;
import com.github.pagehelper.PageHelper;
import com.netflix.discovery.converters.Auto;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.text.SimpleDateFormat;
import java.util.Date;
import java.util.List;

/**
 * @author weichaochao
 * @Title: SocialServiceImpl
 * @date 2018/10/23
 */
@Service("SocialService")
public class SocialServiceImpl implements SocialServiceI {

    @Autowired
    private TpAnnouncementMapper tpAnnouncementMapper;

    @Autowired
    private TpSocialViewMapper tpSocialViewMapper;

    @Autowired
    private TpActivityMapper tpActivityMapper;

    @Autowired
    private TpCarouselSettingMapper tpCarouselSettingMapper;

    @Autowired
    private TpActivitySignupMapper tpActivitySignupMapper;

    @Autowired
    private TpTransactionMapper tpTransactionMapper;

    @Autowired
    private TaSysRoleMapper taSysRoleMapper;

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private  TaSysUserRoleMapper taSysUserRoleMapper;

    @Autowired
    private TpTicketRecordMapper tpTicketRecordMapper;

    @Autowired
    private TpTicketMapper tpTicketMapper;

    @Override
    @Transactional
    public TpAnnouncement findAnnouncementDetail(Integer id, Integer communityId) {
        //TODO
        Integer userId = 1;
        //更新此用户的查看次数操作
        Integer allViewNum = updateSocialView(userId,Constant.ANNOUNCEMENT,communityId,id);
        if (null != allViewNum){
            tpAnnouncementMapper.updateByPrimaryKeySelective(id, allViewNum);
        }
        return tpAnnouncementMapper.selectByPrimaryKey(id, communityId);
    }

    /**
     * 分页获取公告列表
     * @param communityId
     * @param title
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public List<TpAnnouncement> getAnnouncements(Integer communityId,String title, Integer pageNum, Integer pageSize) {
        //使用分页插件
        PageHelper.startPage(pageNum, pageSize);
        // 获取数据
        List<TpAnnouncement> announcementList = tpAnnouncementMapper.getAnnouncements(communityId,title);
        return announcementList;
    }
    /**
     * 根据当前小区ID查出轮播图
     * @param communityId 当前小区ID
     * @return
     */
    @Override
    public List<TpAnnouncement> getAnnouncement(Integer communityId) {
        Integer Num=tpCarouselSettingMapper.getcarouselNum(Constant.ANNOUNCEMENT);
        List<TpAnnouncement> listAnnouncement=tpAnnouncementMapper.getAnnouncement(communityId,Num);
        return listAnnouncement;
    }

    
    /**
     * 分页获取活动列表
     * @param communityId
     * @param title
     * @param pageNum
     * @param pageSize
     * @return
     */
    @Override
    public List<TpActivity> getActivitys(Integer communityId, String title, Integer pageNum, Integer pageSize) {
        //使用分页插件
        PageHelper.startPage(pageNum, pageSize);
        // 获取数据
        List<TpActivity> activityList = tpActivityMapper.getActivitys(communityId,title);
        return activityList;
    }
    
    /**
     * 获取活动帖子详情
     * @param activityId
     * @param communityId
     * @return
     */
    @Override
    public TpActivity findActivityDetail(Integer activityId, Integer communityId) {
        //TODO
        Integer userId = 1;
        //更新查看次数
        Integer allViewNum = updateSocialView(userId,Constant.ACTIVITY,communityId,activityId);
        if (null != allViewNum){
            TpActivity activity = new TpActivity();
            activity.setId(activityId);
            activity.setViewCount(allViewNum);
            tpActivityMapper.updateByPrimaryKeySelective(activity);
        }
        return tpActivityMapper.selectByPrimaryKey(activityId,communityId);
    }
    
    /**
     * 更新此用户的查看次数操作
     * @param userId
     * @param socialType
     * @param communityId
     * @param uuid
     */
    private Integer updateSocialView(Integer userId,String socialType,Integer communityId,Integer uuid) {
        //检查是否查看过这个帖子
        TpSocialView tpSocialView = new TpSocialView();
        tpSocialView.setTaUserId(userId);
        tpSocialView.setSocialType(socialType);
        tpSocialView.setCommunityId(communityId);
        tpSocialView.setUuid(uuid);
        Integer viewNum = tpSocialViewMapper.selectViewNum(tpSocialView);
    
        //查看过的话查看次数加一
        if (viewNum == 0){
            tpSocialView.setCreateDate(new Date());
            tpSocialViewMapper.insertSelective(tpSocialView);
            tpSocialView.setTaUserId(null);
            Integer allViewNum = tpSocialViewMapper.selectViewNum(tpSocialView);
            return allViewNum;
        }
        return null;
    }

    @Override
    public ResponseBean findTaUserInfo(Integer activityId, Integer communityId) {
        ResponseBean responseBean = new ResponseBean();
        TpActivity tpActivity = tpActivityMapper.selectByPrimaryKey(activityId, communityId);
        //判断是否已经过了报名截至时间
        Date registrEndTime = tpActivity.getRegistrationEndTime();
        if (registrEndTime.compareTo(new Date()) < 0){
             responseBean.addError("9997", "已过报名截止时间");
             return responseBean;
        }

        //报名是否超过人数上限
        Integer signUpNum = tpActivitySignupMapper.sumActivitySignUpNum(activityId, communityId);
        if (signUpNum > tpActivity.getSignUpMax()){
            responseBean.addError("9998", "报名人数已满");
            return responseBean;
        }

        //已登陆，身份未知，状态未知



        //判断身份是否为业主且状态为已停用
        //从seession中获取的user_id
        //TODO
        TaSysRole sysRole = taSysRoleMapper.findRoleByUserId(1);
        TaUser taUser = taUserMapper.selectByPrimaryKey(1);
        if (Constant.INVALID.equals(taUser.getStatus())
            && Constant.OWNER.equals(sysRole.getRoleName())){

            return insertActivitySignUp(tpActivity, communityId);
        }

        //身份为家属租客，状态为已停用
        if (Constant.INVALID.equals(taUser.getStatus())
            && (Constant.FAMILYMEMBER.equals(sysRole.getRoleName())) || Constant.TENANT.equals(sysRole.getRoleName())){

            return insertActivitySignUp(tpActivity, communityId);
        }

        if (Constant.EFFECTIVE.equals(taUser.getStatus())
                && (Constant.FAMILYMEMBER.equals(sysRole.getRoleName()))
                || Constant.TENANT.equals(sysRole.getRoleName())
                || Constant.OWNER.equals(sysRole.getRoleName())){
            return insertActivitySignUp(tpActivity, communityId);
        }
        responseBean.addError("9999", "服务器异常");
        return responseBean;
    }

    @Override
    public List<TpTransaction> findAllTransaction(Integer communityId, String type, Integer pageNum, Integer paeSize) {
        PageHelper.startPage(pageNum, paeSize);
        return tpTransactionMapper.findAllTransaction(communityId, type);
    }

    @Transactional
    @Override
    public ResponseBean stopTpTicketRecord(Integer communityId, Integer ticketId) {
        ResponseBean responseBean = new ResponseBean();
        try{
            TpTicket tpTicket = new TpTicket();
            tpTicket.setStatus("6");
            tpTicket.setId(ticketId);
            tpTicketMapper.updateByPrimaryKeySelective(tpTicket);

            TpTicketRecord tpTicketRecord = new TpTicketRecord();
            tpTicketRecord.setStatus("6");
            tpTicketRecord.setTicketId(ticketId);
            tpTicketRecord.setCommunityId(communityId);
            //TODO
            tpTicketRecord.setCreateUser(1);
            tpTicketRecord.setCreateDate(new Date());
            tpTicketRecordMapper.insertSelective(tpTicketRecord);
            return responseBean;
        }catch(Exception e){
            e.printStackTrace();
            responseBean.addError("服务器异常");
            return responseBean;
        }
    }

    @Override
    public void updateTicketContent(Integer ticketId, TpTicket tpTicket, String type) {
        tpTicket.setId(ticketId);
        tpTicket.setType(type);
        tpTicketMapper.updateByPrimaryKeySelective(tpTicket);
    }

    @Override
    public ResponseBean addAllTransaction(Integer userId, TpTransaction tpTransaction) {
        ResponseBean response = new ResponseBean();
        TaUser user=taUserMapper.selectByPrimaryKey(userId);
        tpTransaction.setCommunityId(user.getCommunityId());
        tpTransaction.setTaUserId(userId);
        tpTransaction.setCreateUser(userId);
        tpTransaction.setCreateDate(new Date());
        tpTransaction.setUpdateUser(userId);
        tpTransaction.setUpdateDate(new Date());
        tpTransactionMapper.insert(tpTransaction);
        response.addSuccess("发布成功");
        return response;
    }

    @Override
    public ResponseBean selectAllTransaction(Integer userId,Integer pageNum,Integer paeSize) {
        PageHelper.startPage(pageNum, paeSize);
        ResponseBean responseBean = new ResponseBean();
        TaUser user=taUserMapper.selectByPrimaryKey(userId);
         Integer communityId=user.getCommunityId();
        List<TpTransaction> tpTransactions=tpTransactionMapper.selectTransaction(userId,communityId);
        responseBean.addSuccess(tpTransactions);
        return responseBean;
    }

    @Override
    public ResponseBean updateTransaction(TpTransaction tpTransaction,Integer userId) {
        ResponseBean response = new ResponseBean();
        TaUser user=taUserMapper.selectByPrimaryKey(userId);
        tpTransaction.setCommunityId(user.getCommunityId());
        tpTransaction.setTaUserId(userId);
        tpTransaction.setCreateUser(userId);
        tpTransaction.setStatus("2");
        tpTransaction.setCreateDate(new Date());
        tpTransaction.setUpdateUser(userId);
        tpTransaction.setUpdateDate(new Date());
        tpTransactionMapper.updateByPrimaryKey(tpTransaction);
        response.addSuccess("修改成功");
        return response;
    }

    @Override
    public void accessTicket(Integer communityId, TpTicket tpTicket, String ticketId) {
        //修改工单内容和评分
        tpTicket.setId(Integer.valueOf(ticketId));
        tpTicket.setStatus("5");
        tpTicketMapper.updateByPrimaryKeySelective(tpTicket);

        //工单处理表新增评分记录
        TpTicketRecord record = new TpTicketRecord();
        record.setCommunityId(communityId);
        record.setTicketId(Integer.valueOf(ticketId));
        record.setStatus("5");
        //todo
        record.setCreateUser(1);
        record.setCreateDate(new Date());
        tpTicketRecordMapper.insertSelective(record);
    }

    public ResponseBean insertActivitySignUp(TpActivity tpActivity, Integer communityId){
        ResponseBean responseBean = new ResponseBean();
        //判断是否已经报名
        //todo
        Integer signNum = tpActivitySignupMapper.findTpActivetitySignByUserId(tpActivity.getId(), communityId, 1);
        if (signNum != 0){
            responseBean.addError("9996", "您已报名，请勿重复报名");
            return responseBean;
        }

        TpActivitySignup tpActivitySignup = new TpActivitySignup();
        tpActivitySignup.setActivityId(tpActivity.getId());
        tpActivitySignup.setCommunityId(communityId);
        tpActivitySignup.setTaUserId(1);
        tpActivitySignup.setSignUpTime(new Date());
        tpActivitySignupMapper.insertSelective(tpActivitySignup);
        responseBean.addSuccess("报名成功");
        return responseBean;
    }

    @Transactional
    @Override
    public TpTransaction findUsedDetails(Integer activityId, Integer communityId, Integer userId) {
        Integer num = updateSocialView(userId,Constant.LEASE,communityId,activityId);
        if (null != num){
            TpTransaction transaction = new TpTransaction();
            transaction.setId(activityId);
            transaction.setViewCount(num);
            tpTransactionMapper.updateByPrimaryKeySelective(transaction);
        }
        return tpTransactionMapper.selectByPrimaryKey(activityId,communityId);

    }
}
