package com.community.huiju.service.impl;

import com.alibaba.fastjson.JSONObject;
import com.community.commom.mode.ResponseBean;
import com.community.commom.utils.AccountValidatorUtil;
import com.community.commom.utils.MD5Utils;
import com.community.huiju.common.code.cache.AppkeyCache;
import com.community.huiju.dao.*;
import com.community.huiju.model.*;
import com.community.huiju.service.ITaUserService;
import com.community.huiju.vo.TaUserVO;
import com.google.common.collect.Maps;
import com.sun.org.apache.bcel.internal.generic.IF_ACMPEQ;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.checkerframework.checker.units.qual.A;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * 用户业务 实现
 * @author weiximei
 */
@Service("iTaUserService")
@Slf4j
public class TaUserServiceImpl implements ITaUserService {

    @Autowired
    private TaUserMapper taUserMapper;

    @Autowired
    private TpBuildingOwnerInfoMapper tpBuildingOwnerInfoMapper;

    @Autowired
    private TaSysRoleMapper taSysRoleMapper;

    @Autowired
    private TaSysUserRoleMapper taSysUserRoleMapper;

    @Autowired
    private ToCommunitiesMapper toCommunitiesMapper;

    @Autowired
    private SysNationMapper sysNationMapper;

    @Transactional
    @Override
    public ResponseBean login(TaUser user) {
        ResponseBean response = new ResponseBean();
        log.info("{} 手机号校验结果: {}",user.getLoginName(),AccountValidatorUtil.isPhone(user.getLoginName()));
        if (!AccountValidatorUtil.isPhone(user.getLoginName())){
            response.addError("请输入正取的手机号!");
            return response;
        }
        Map<String,Object> map = Maps.newHashMap();
        map.put("loginName",user.getLoginName());
        map.put("loginPassword",MD5Utils.encode(user.getLoginPassword()));
        TaUser currentUser = taUserMapper.selectByLoginNameAndByLoginPassword(map);
        if (null != currentUser){
            response.addSuccess(currentUser);
            return response;
        }else {
            // 1.用户在库中,不在则注册一个
            TaUser isTaUser = taUserMapper.selectByLoginName(map);
            if (null == isTaUser) {
                ResponseBean result = register(user);
                response.addSuccess(response.getData());
            }else {
                response.addError("用户名或者密码错误!");
            }

        }
        return response;
    }

    @Override
    public ResponseBean login(String loginName,String communityId,String code) {
        ResponseBean response = new ResponseBean();
        String phoneCode = (String) AppkeyCache.getCache(loginName);
        if (!phoneCode.equals(code)) {
            response.addError("验证码错误!");
            return response;
        }
        // 设置验证码为null字符
        AppkeyCache.setCache(loginName,"null");
        log.info("{} 手机号校验结果: {}",loginName,AccountValidatorUtil.isPhone(loginName));
        if (!AccountValidatorUtil.isPhone(loginName)){
            response.addError("请输入正取的手机号!");
            return response;
        }
        if (StringUtils.isBlank(communityId)) {
            response.addError("请选择小区!");
            return response;
        }
        if (StringUtils.isBlank(code)) {
            response.addError("请输入验证码!");
            return response;
        }

        Map<String,Object> map = Maps.newHashMap();
        map.put("loginName",loginName);
        TaUser currentUser = taUserMapper.selectByLoginName(map);
        if (null != currentUser){
            if (!communityId.equals(currentUser.getCommunityId()+"")) {
                response.addError("用户不在此小区!");
                return response;
            }
            TaUserVO taUserVO = new TaUserVO();
            BeanUtils.copyProperties(currentUser,taUserVO);
            response.addSuccess(taUserVO);
            return response;
        }else {
            TaUser user = new TaUser();
            user.setLoginName(loginName);
            ResponseBean result = register(user);
            response.addSuccess(result.getData());
        }
        return response;
    }

    @Transactional
    @Override
    public ResponseBean register(TaUser user) {

        // TODO 注册逻辑需要完善
        /**
         * 1.自动生成账号的基本信息
         * 2.匹配资料库 已认证 未认证
         * 2.角色类型
         *
         * 具体看原型图
         *
         */

        ResponseBean<TaUserVO> response = new ResponseBean();
        // 开始注册
        user.setCreateDate(new Date());
        user.setUpdateDate(new Date());
        user.setStatus("1");
        user.setAcceptAgreementStatus("1");
        user.setUserName(user.getLoginName());
        user.setRemark("这是系统自动注册!");
        user.setCommunityId(3);
        user.setVerifyStatus("1");
        //user.setLoginPassword(MD5Utils.encode(user.getLoginPassword()));
        taUserMapper.insertSelective(user);

        TaUserVO taUserVO = new TaUserVO();
        BeanUtils.copyProperties(user,taUserVO);
        response.addSuccess(taUserVO);
        return response;
    }
    @Transactional
    @Override
    public ResponseBean udDateloginName(Integer id, String paramets) {
        ResponseBean response = new ResponseBean();

        JSONObject jsonObject = JSONObject.parseObject(paramets);
        String phone = (String) jsonObject.get("phone");
        String code = (String) jsonObject.get("code");

        TaUser user=taUserMapper.selectByPrimaryKey(id);
        //系统验证码
        String  codes= (String) AppkeyCache.getCache(phone);
        //用户电话
            /*String  phones=user.getLoginName();*/
        if(codes.equals(code)){
            TaUser taUser=new TaUser();
            taUser.setLoginName(phone);
            taUser.setId(user.getId());
            taUserMapper.ubdateLongName(taUser);
             response.addSuccess("修改成功");
            AppkeyCache.setCache(user.getLoginName(),"null");
            return response;
        }else {
            response.addError("验证码错误");
            return response;
        }



    }

    @Override
    public List<TaUser> getAllRoomUserList(Integer parentId) {
        return taUserMapper.selectUserListByParentId(parentId);
    }

    @Transactional
    @Override
    public ResponseBean modifyUser(TaUser user) {

        ResponseBean response = new ResponseBean();

        TaUser taUser = taUserMapper.selectByPrimaryKey(user.getId());
        BeanUtils.copyProperties(user,taUser);

        int result = taUserMapper.updateByPrimaryKeySelective(taUser);

        if (result > 0){
            response.addSuccess("修改成功!");
        }else {
            response.addError("修改失败!");
        }

        return response;
    }

    @Transactional
    @Override
    public ResponseBean startOrEndUsingUser(Integer currentUserId, Integer userId, Integer type) {
        ResponseBean response = null;
        if ("1".equals(type)){
            response = startAndEnd(currentUserId,userId,true);
        } else {
            response = startAndEnd(currentUserId,userId,false);
        }
        return response;
    }

    /**
     *  用户停用和启用
     * @param currentUserId 当前用户(业主)
     * @param userId 租客或者家属
     * @param bool 启用为 true  停用为 false
     * @return
     */
    private ResponseBean startAndEnd(Integer currentUserId, Integer userId, boolean bool){

        // TODO 更新人字段需要待定
        /**
         * 更新人 是业主 还是 物业
         */

        ResponseBean response = new ResponseBean();

        TaUser user = taUserMapper.selectByPrimaryKey(userId);
        if (null == user) {
            response.addError("该用户不存在!");
            return response;
        }
        if (!currentUserId.equals(user.getParentId())) {
            response.addError("该用户不是您的家属或租客!");
            return response;
        }
        if (bool) {
            if ("1".equals(user.getStatus())) {
                response.addError("用户已启用!");
                return response;
            }
            user.setStatus("1");
        } else {
            if ("0".equals(user.getStatus())) {
                response.addError("用户已停用!");
                return response;
            }
            user.setStatus("0");
        }

        int result = taUserMapper.updateByPrimaryKeySelective(user);
        if (result > 0) {
            response.addSuccess(bool==true?"用户启用成功!":"用户停用成功!");
        } else {
            response.addError(bool==true?"用户启用失败!":"用户停用失败!");
        }

        return response;
    }

    @Transactional
    @Override
    public ResponseBean addTenantsOrDependents(String userName, String phone, String gender, Integer currentUserId, Integer type) {
        ResponseBean response = new ResponseBean();

        TaUser taUser = taUserMapper.selectByPrimaryKey(currentUserId);
        if (null == taUser) {
            response.addError("此用户不存在!");
            return response;
        }
        if (taUser.getVerifyStatus().equals("0") || taUser.getVerifyStatus().equals("2")) {
            response.addError("对不起,您未认证或认证已作废!");
            return response;
        }

        TaUser user = new TaUser();
        user.setUserName(userName);
        user.setLoginName(phone);
        user.setGender(gender);
        user.setCreateDate(new Date());
        user.setCreateUser(currentUserId);
        user.setUpdateDate(new Date());
        user.setUpdateUser(currentUserId);
        user.setParentId(currentUserId);
        user.setStatus("1");
        user.setVerifyStatus("1");
        user.setAcceptAgreementStatus("1");
        user.setRemark("这是业主添加的!");
        user.setUserName(user.getLoginName());
        user.setBuildingOwnerInfoId(taUser.getBuildingOwnerInfoId());
        user.setCommunityId(taUser.getCommunityId());

        int result = taUserMapper.insertSelective(user);
        if (result < 0) {
            response.addError("添加失败!");
            return response;
        }

        // 先查询角色 在角色关联记录
        // 这里的 2 或者 3 是对应角色编号
        int roleType = type.equals("0") ? 2 : 3;
        TaSysRole taSysRole = taSysRoleMapper.selectByPrimaryKey(roleType);
        if (null == taSysRole) {
            response.addError("该权限不存在!");
            log.error("这个角色没有找到!角色名称:{} 角色编号:{}",type.equals("0") ? "租客" : "家属",roleType);
            return response;
        }

        TaSysUserRole taSysUserRole = new TaSysUserRole();
        taSysUserRole.setCommunityId(user.getCommunityId());
        taSysUserRole.setRoleId(taSysRole.getId());
        taSysUserRole.setUserId(user.getId());
        try {
            int resultRole = taSysUserRoleMapper.insertSelective(taSysUserRole);
            if (resultRole > 0) {
                response.addSuccess("添加成功!");
            } else {
                throw new RuntimeException("租客或者家属角色权限添加失败");
            }
        } catch (Exception e) {
            response.addSuccess("添加失败!");
            log.error("租客或者家属角色权限添加失败!",e);
            throw new RuntimeException("租客或者家属角色权限添加失败");
        }

        return response;
    }

    @Transactional
    @Override
    public ResponseBean modifyUserHeadPortrait(Integer currentUserId, String headPortrait) {

        ResponseBean response = new ResponseBean();

        TaUser user = taUserMapper.selectByPrimaryKey(currentUserId);
        user.setHeadPortrait(headPortrait);

        int result = taUserMapper.updateByPrimaryKeySelective(user);
        if (result > 0) {
            response.addSuccess("修改成功!");
        } else {
          response.addError("修改失败!");
        }

        return response;
    }

    @Override
    public ResponseBean getUserInfo(Integer userId) {

        ResponseBean response = new ResponseBean();
        if (null == userId) {
            response.addError("用户id不存在!");
            return response;
        }

        // 获取用户
        TaUser user = taUserMapper.selectByPrimaryKey(userId);
        // 获取业主信息
        TpBuildingOwnerInfo tpBuildingOwnerInfo = tpBuildingOwnerInfoMapper.selectByPrimaryKey(user.getBuildingOwnerInfoId());
        // 获取小区
        ToCommunities toCommunities = toCommunitiesMapper.selectByPrimaryKey(tpBuildingOwnerInfo.getCommunityId());

        // 省
        SysNation province = sysNationMapper.selectByPrimaryKey(toCommunities.getProvinceId());
        // 市
        SysNation city = sysNationMapper.selectByPrimaryKey(toCommunities.getCityId());
        // 区
        SysNation district = sysNationMapper.selectByPrimaryKey(toCommunities.getDistrictId());

        TaUserVO userVO = new TaUserVO();
        BeanUtils.copyProperties(user,userVO);
        userVO.setAddressProvince(province.getProvince()+""+city.getCity()+""+district.getDistrict());
        userVO.setAddressBuilding(tpBuildingOwnerInfo.getBuilding()
                +tpBuildingOwnerInfo.getUnit()
                +tpBuildingOwnerInfo.getLevel()
                +tpBuildingOwnerInfo.getRoomNo());
        userVO.setCommunityName(toCommunities.getCommunityName());

        response.addSuccess(userVO);

        return response;
    }
}
